Class: BmcApi::EsxiDatastoreConfiguration
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- BmcApi::EsxiDatastoreConfiguration
- Defined in:
- lib/pnap_bmc_api/models/esxi_datastore_configuration.rb
Overview
Esxi data storage configuration.
Instance Attribute Summary collapse
-
#datastore_name ⇒ Object
Datastore name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EsxiDatastoreConfiguration
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EsxiDatastoreConfiguration
Initializes the object
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 54 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::EsxiDatastoreConfiguration` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::EsxiDatastoreConfiguration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'datastore_name') self.datastore_name = attributes[:'datastore_name'] else self.datastore_name = nil end end |
Instance Attribute Details
#datastore_name ⇒ Object
Datastore name
20 21 22 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 20 def datastore_name @datastore_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
30 31 32 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 30 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
35 36 37 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 35 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 23 def self.attribute_map { :'datastore_name' => :'datastoreName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 157 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
47 48 49 50 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 47 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 40 def self.openapi_types { :'datastore_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 136 def ==(o) return true if self.equal?(o) self.class == o.class && datastore_name == o.datastore_name end |
#eql?(o) ⇒ Boolean
144 145 146 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 144 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 150 def hash [datastore_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 77 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @datastore_name.nil? invalid_properties.push('invalid value for "datastore_name", datastore_name cannot be nil.') end if @datastore_name.to_s.length > 42 invalid_properties.push('invalid value for "datastore_name", the character length must be smaller than or equal to 42.') end if @datastore_name.to_s.length < 1 invalid_properties.push('invalid value for "datastore_name", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^[a-zA-Z0-9]+$/) if @datastore_name !~ pattern invalid_properties.push("invalid value for \"datastore_name\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 179 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
102 103 104 105 106 107 108 109 |
# File 'lib/pnap_bmc_api/models/esxi_datastore_configuration.rb', line 102 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @datastore_name.nil? return false if @datastore_name.to_s.length > 42 return false if @datastore_name.to_s.length < 1 return false if @datastore_name !~ Regexp.new(/^[a-zA-Z0-9]+$/) true end |