Class: BmcApi::IpBlocksConfiguration
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- BmcApi::IpBlocksConfiguration
- Defined in:
- lib/pnap_bmc_api/models/ip_blocks_configuration.rb
Overview
The IP blocks to assign to this server. This is an exclusive allocation, i.e. the IP blocks cannot be shared with other servers. If IpBlocksConfiguration is not defined, the purchase of a new IP block is determined by the networkType field.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#configuration_type ⇒ Object
(Write-only) Determines the approach for configuring IP blocks for the server being provisioned.
-
#ip_blocks ⇒ Object
Used for specifying the previously purchased IPv4 blocks to assign to this server upon provisioning.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IpBlocksConfiguration
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IpBlocksConfiguration
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::IpBlocksConfiguration` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::IpBlocksConfiguration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'configuration_type') self.configuration_type = attributes[:'configuration_type'] else self.configuration_type = 'PURCHASE_NEW' end if attributes.key?(:'ip_blocks') if (value = attributes[:'ip_blocks']).is_a?(Array) self.ip_blocks = value end end end |
Instance Attribute Details
#configuration_type ⇒ Object
(Write-only) Determines the approach for configuring IP blocks for the server being provisioned. If PURCHASE_NEW is selected, the smallest supported range, depending on the operating system, is allocated to the server.
20 21 22 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 20 def configuration_type @configuration_type end |
#ip_blocks ⇒ Object
Used for specifying the previously purchased IPv4 blocks to assign to this server upon provisioning. Used alongside the USER_DEFINED configurationType.
23 24 25 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 23 def ip_blocks @ip_blocks end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 48 def self.attribute_map { :'configuration_type' => :'configurationType', :'ip_blocks' => :'ipBlocks' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 178 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 74 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 66 def self.openapi_types { :'configuration_type' => :'String', :'ip_blocks' => :'Array<ServerIpBlock>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
156 157 158 159 160 161 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 156 def ==(o) return true if self.equal?(o) self.class == o.class && configuration_type == o.configuration_type && ip_blocks == o.ip_blocks end |
#eql?(o) ⇒ Boolean
165 166 167 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 165 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
171 172 173 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 171 def hash [configuration_type, ip_blocks].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@ip_blocks.nil? && @ip_blocks.length > 1 invalid_properties.push('invalid value for "ip_blocks", number of items must be less than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
122 123 124 125 126 127 128 |
# File 'lib/pnap_bmc_api/models/ip_blocks_configuration.rb', line 122 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' configuration_type_validator = EnumAttributeValidator.new('String', ["PURCHASE_NEW", "USER_DEFINED", "NONE"]) return false unless configuration_type_validator.valid?(@configuration_type) return false if !@ip_blocks.nil? && @ip_blocks.length > 1 true end |