Class: BmcApi::NetworkConfiguration
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- BmcApi::NetworkConfiguration
- Defined in:
- lib/pnap_bmc_api/models/network_configuration.rb
Overview
Entire network details of bare metal server.
Instance Attribute Summary collapse
-
#gateway_address ⇒ Object
The address of the gateway assigned / to assign to the server.
When used as part of request body, IP address has to be part of a private/public network or an IP block assigned to this server.
Gateway address also has to be assigned on an already deployed resource unless the address matches the BMC gateway address in a public network/IP block or the ‘force` query parameter is true. -
#ip_blocks_configuration ⇒ Object
Returns the value of attribute ip_blocks_configuration.
-
#private_network_configuration ⇒ Object
Returns the value of attribute private_network_configuration.
-
#public_network_configuration ⇒ Object
Returns the value of attribute public_network_configuration.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NetworkConfiguration
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NetworkConfiguration
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 66 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::NetworkConfiguration` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::NetworkConfiguration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'gateway_address') self.gateway_address = attributes[:'gateway_address'] end if attributes.key?(:'private_network_configuration') self.private_network_configuration = attributes[:'private_network_configuration'] end if attributes.key?(:'ip_blocks_configuration') self.ip_blocks_configuration = attributes[:'ip_blocks_configuration'] end if attributes.key?(:'public_network_configuration') self.public_network_configuration = attributes[:'public_network_configuration'] end end |
Instance Attribute Details
#gateway_address ⇒ Object
The address of the gateway assigned / to assign to the server.
When used as part of request body, IP address has to be part of a private/public network or an IP block assigned to this server.
Gateway address also has to be assigned on an already deployed resource unless the address matches the BMC gateway address in a public network/IP block or the ‘force` query parameter is true.
20 21 22 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 20 def gateway_address @gateway_address end |
#ip_blocks_configuration ⇒ Object
Returns the value of attribute ip_blocks_configuration.
24 25 26 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 24 def ip_blocks_configuration @ip_blocks_configuration end |
#private_network_configuration ⇒ Object
Returns the value of attribute private_network_configuration.
22 23 24 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 22 def private_network_configuration @private_network_configuration end |
#public_network_configuration ⇒ Object
Returns the value of attribute public_network_configuration.
26 27 28 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 26 def public_network_configuration @public_network_configuration end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
39 40 41 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 39 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
44 45 46 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 44 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 29 def self.attribute_map { :'gateway_address' => :'gatewayAddress', :'private_network_configuration' => :'privateNetworkConfiguration', :'ip_blocks_configuration' => :'ipBlocksConfiguration', :'public_network_configuration' => :'publicNetworkConfiguration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 138 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
59 60 61 62 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 59 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 49 def self.openapi_types { :'gateway_address' => :'String', :'private_network_configuration' => :'PrivateNetworkConfiguration', :'ip_blocks_configuration' => :'IpBlocksConfiguration', :'public_network_configuration' => :'PublicNetworkConfiguration' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
114 115 116 117 118 119 120 121 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 114 def ==(o) return true if self.equal?(o) self.class == o.class && gateway_address == o.gateway_address && private_network_configuration == o.private_network_configuration && ip_blocks_configuration == o.ip_blocks_configuration && public_network_configuration == o.public_network_configuration end |
#eql?(o) ⇒ Boolean
125 126 127 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 125 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
131 132 133 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 131 def hash [gateway_address, private_network_configuration, ip_blocks_configuration, public_network_configuration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
99 100 101 102 103 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 99 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 160 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
107 108 109 110 |
# File 'lib/pnap_bmc_api/models/network_configuration.rb', line 107 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |