Class: BmcApi::OsConfigurationIPXE
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- BmcApi::OsConfigurationIPXE
- Defined in:
- lib/pnap_bmc_api/models/os_configuration_ipxe.rb
Overview
iPXE configuration details. Configures the server to boot using the iPXE network boot firmware with a custom boot script. Only applicable when osName is ‘ipxe’ and must not be provided for any other OS.
Instance Attribute Summary collapse
-
#native_vlan_configuration ⇒ Object
Returns the value of attribute native_vlan_configuration.
-
#url ⇒ Object
The URL of the iPXE boot script used to start the server.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OsConfigurationIPXE
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OsConfigurationIPXE
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::OsConfigurationIPXE` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::OsConfigurationIPXE`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'native_vlan_configuration') self.native_vlan_configuration = attributes[:'native_vlan_configuration'] end end |
Instance Attribute Details
#native_vlan_configuration ⇒ Object
Returns the value of attribute native_vlan_configuration.
22 23 24 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 22 def native_vlan_configuration @native_vlan_configuration end |
#url ⇒ Object
The URL of the iPXE boot script used to start the server.
20 21 22 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 20 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 25 def self.attribute_map { :'url' => :'url', :'native_vlan_configuration' => :'nativeVlanConfiguration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 148 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 43 def self.openapi_types { :'url' => :'String', :'native_vlan_configuration' => :'OsConfigurationIPXENativeVlanConfiguration' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 126 def ==(o) return true if self.equal?(o) self.class == o.class && url == o.url && native_vlan_configuration == o.native_vlan_configuration end |
#eql?(o) ⇒ Boolean
135 136 137 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 135 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
141 142 143 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 141 def hash [url, native_vlan_configuration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 85 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end pattern = Regexp.new(/^https?:\/\/.+$/) if @url !~ pattern invalid_properties.push("invalid value for \"url\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 170 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
102 103 104 105 106 107 |
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe.rb', line 102 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @url.nil? return false if @url !~ Regexp.new(/^https?:\/\/.+$/) true end |