Class: BmcApi::OsConfigurationIPXENativeVlanConfiguration

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb

Overview

Specifies the native VLAN configuration for the server.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OsConfigurationIPXENativeVlanConfiguration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::OsConfigurationIPXENativeVlanConfiguration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::OsConfigurationIPXENativeVlanConfiguration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'vlan_id')
    self.vlan_id = attributes[:'vlan_id']
  end

  if attributes.key?(:'static_dhcp_address_v4')
    self.static_dhcp_address_v4 = attributes[:'static_dhcp_address_v4']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#static_dhcp_address_v4Object

The static IP V4 address assigned to the server within the native VLAN. This address is set as the DHCP reservation and used for the iPXE boot process. Value must be an available/unused IP V4 address within the native network usable IP range. If omitted, the first available IP in the native network will be automatically assigned. Therefore, at least one IP must be available within the native network.



23
24
25
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 23

def static_dhcp_address_v4
  @static_dhcp_address_v4
end

#statusObject

(Read-only) The status of the native VLAN configuration.



26
27
28
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 26

def status
  @status
end

#vlan_idObject

The VLAN ID of the network to be used as the native VLAN. The value must reference a public network with IP V4 block(s) or a public IP V4 block network to which the server is (or will be) attached. If omitted during provisioning, the native VLAN is matched to the configured/auto-purchased public IP V4 block. If no public IP block is available, a VLAN ID must be provided. The VLAN ID must belong to one of the public networks for any of the specified servers. During post-provisioning, if Native VLAN is omitted, the server will be configured with no native VLAN. If provided, the VLAN ID must be specified and must belong to any of the existing server public networks or IP block networks attached to the server.



20
21
22
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 20

def vlan_id
  @vlan_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 51

def self.attribute_map
  {
    :'vlan_id' => :'vlanId',
    :'static_dhcp_address_v4' => :'staticDhcpAddressV4',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 186

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 70

def self.openapi_types
  {
    :'vlan_id' => :'Integer',
    :'static_dhcp_address_v4' => :'String',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



163
164
165
166
167
168
169
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      vlan_id == o.vlan_id &&
      static_dhcp_address_v4 == o.static_dhcp_address_v4 &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 173

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



179
180
181
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 179

def hash
  [vlan_id, static_dhcp_address_v4, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



115
116
117
118
119
120
121
122
123
124
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 115

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)(\.)){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/)
  if !@static_dhcp_address_v4.nil? && @static_dhcp_address_v4 !~ pattern
    invalid_properties.push("invalid value for \"static_dhcp_address_v4\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 208

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



128
129
130
131
132
133
134
# File 'lib/pnap_bmc_api/models/os_configuration_ipxe_native_vlan_configuration.rb', line 128

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@static_dhcp_address_v4.nil? && @static_dhcp_address_v4 !~ Regexp.new(/^((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)(\.)){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/)
  status_validator = EnumAttributeValidator.new('String', ["in-progress", "assigned", "error"])
  return false unless status_validator.valid?(@status)
  true
end