Class: BmcApi::OsConfigurationMapProxmox

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb

Overview

Proxmox VE configuration properties.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OsConfigurationMapProxmox

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::OsConfigurationMapProxmox` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::OsConfigurationMapProxmox`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'root_password')
    self.root_password = attributes[:'root_password']
  end

  if attributes.key?(:'management_ui_url')
    self.management_ui_url = attributes[:'management_ui_url']
  end

  if attributes.key?(:'management_access_allowed_ips')
    if (value = attributes[:'management_access_allowed_ips']).is_a?(Array)
      self.management_access_allowed_ips = value
    end
  end
end

Instance Attribute Details

#management_access_allowed_ipsObject

List of IPs allowed to access the Management UI. Supported in single IP, CIDR and range format. When undefined, Management UI is disabled. This will only be returned in response to provisioning a server.



26
27
28
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 26

def management_access_allowed_ips
  @management_access_allowed_ips
end

#management_ui_urlObject

(Read-only) The URL of the management UI which will only be returned in response to provisioning a server.



23
24
25
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 23

def management_ui_url
  @management_ui_url
end

#root_passwordObject

(Read-only) Password set for user root on a Proxmox server which will only be returned in response to provisioning a server.



20
21
22
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 20

def root_password
  @root_password
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 29

def self.attribute_map
  {
    :'root_password' => :'rootPassword',
    :'management_ui_url' => :'managementUiUrl',
    :'management_access_allowed_ips' => :'managementAccessAllowedIps'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 152

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 48

def self.openapi_types
  {
    :'root_password' => :'String',
    :'management_ui_url' => :'String',
    :'management_access_allowed_ips' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



129
130
131
132
133
134
135
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 129

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      root_password == o.root_password &&
      management_ui_url == o.management_ui_url &&
      management_access_allowed_ips == o.management_access_allowed_ips
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


139
140
141
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 139

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



145
146
147
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 145

def hash
  [root_password, management_ui_url, management_access_allowed_ips].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



95
96
97
98
99
100
101
102
103
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 95

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@management_access_allowed_ips.nil? && @management_access_allowed_ips.length < 1
    invalid_properties.push('invalid value for "management_access_allowed_ips", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 174

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



107
108
109
110
111
# File 'lib/pnap_bmc_api/models/os_configuration_map_proxmox.rb', line 107

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@management_access_allowed_ips.nil? && @management_access_allowed_ips.length < 1
  true
end