Class: BmcApi::OsConfigurationNetrisController
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- BmcApi::OsConfigurationNetrisController
- Defined in:
- lib/pnap_bmc_api/models/os_configuration_netris_controller.rb
Overview
Netris Controller configuration properties. Knowledge base article to help you can be found <a href=‘phoenixnap.com/kb/netris-bare-metal-cloud#deploy-netris-controller’ target=‘_blank’>here</a>.
Instance Attribute Summary collapse
-
#host_os ⇒ Object
(Read-only) Host OS on which the Netris Controller is installed.
-
#netris_user_password ⇒ Object
(Read-only) Auto-generated password set for user ‘netris’ in the web console.
The password is not stored and therefore will only be returned in response to provisioning a server. -
#netris_web_console_url ⇒ Object
(Read-only) The URL for the Netris Controller web console.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OsConfigurationNetrisController
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OsConfigurationNetrisController
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::OsConfigurationNetrisController` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::OsConfigurationNetrisController`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'host_os') self.host_os = attributes[:'host_os'] end if attributes.key?(:'netris_web_console_url') self.netris_web_console_url = attributes[:'netris_web_console_url'] end if attributes.key?(:'netris_user_password') self.netris_user_password = attributes[:'netris_user_password'] end end |
Instance Attribute Details
#host_os ⇒ Object
(Read-only) Host OS on which the Netris Controller is installed.
20 21 22 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 20 def host_os @host_os end |
#netris_user_password ⇒ Object
(Read-only) Auto-generated password set for user ‘netris’ in the web console.
The password is not stored and therefore will only be returned in response to provisioning a server. Copy and save it for future reference.
26 27 28 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 26 def netris_user_password @netris_user_password end |
#netris_web_console_url ⇒ Object
(Read-only) The URL for the Netris Controller web console. It will only be returned in response to provisioning a server.
23 24 25 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 23 def netris_web_console_url @netris_web_console_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 29 def self.attribute_map { :'host_os' => :'hostOs', :'netris_web_console_url' => :'netrisWebConsoleUrl', :'netris_user_password' => :'netrisUserPassword' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 131 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 48 def self.openapi_types { :'host_os' => :'String', :'netris_web_console_url' => :'String', :'netris_user_password' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
108 109 110 111 112 113 114 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 108 def ==(o) return true if self.equal?(o) self.class == o.class && host_os == o.host_os && netris_web_console_url == o.netris_web_console_url && netris_user_password == o.netris_user_password end |
#eql?(o) ⇒ Boolean
118 119 120 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 118 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
124 125 126 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 124 def hash [host_os, netris_web_console_url, netris_user_password].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
93 94 95 96 97 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 93 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 153 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
101 102 103 104 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_controller.rb', line 101 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |