Class: BmcApi::OsConfigurationWindows

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_bmc_api/models/os_configuration_windows.rb

Overview

Windows OS configuration properties.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OsConfigurationWindows

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 59

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::OsConfigurationWindows` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::OsConfigurationWindows`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'rdp_allowed_ips')
    if (value = attributes[:'rdp_allowed_ips']).is_a?(Array)
      self.rdp_allowed_ips = value
    end
  end

  if attributes.key?(:'bring_your_own_license')
    self.bring_your_own_license = attributes[:'bring_your_own_license']
  else
    self.bring_your_own_license = false
  end
end

Instance Attribute Details

#bring_your_own_licenseObject

Use a Bring Your Own (BYO) Windows license. If true, the server is provisioned in trial mode, and you must activate your own license. If false (default), the server includes a managed Windows license billed by the platform.



23
24
25
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 23

def bring_your_own_license
  @bring_your_own_license
end

#rdp_allowed_ipsObject

List of IPs allowed for RDP access to Windows OS. Supported in single IP, CIDR and range format. When undefined, RDP is disabled. To allow RDP access from any IP use 0.0.0.0/0. This will only be returned in response to provisioning a server.



20
21
22
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 20

def rdp_allowed_ips
  @rdp_allowed_ips
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 26

def self.attribute_map
  {
    :'rdp_allowed_ips' => :'rdpAllowedIps',
    :'bring_your_own_license' => :'bringYourOwnLicense'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 144

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



52
53
54
55
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 52

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 44

def self.openapi_types
  {
    :'rdp_allowed_ips' => :'Array<String>',
    :'bring_your_own_license' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



122
123
124
125
126
127
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 122

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      rdp_allowed_ips == o.rdp_allowed_ips &&
      bring_your_own_license == o.bring_your_own_license
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


131
132
133
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 131

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



137
138
139
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 137

def hash
  [rdp_allowed_ips, bring_your_own_license].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



88
89
90
91
92
93
94
95
96
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 88

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@rdp_allowed_ips.nil? && @rdp_allowed_ips.length < 1
    invalid_properties.push('invalid value for "rdp_allowed_ips", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 166

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



100
101
102
103
104
# File 'lib/pnap_bmc_api/models/os_configuration_windows.rb', line 100

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@rdp_allowed_ips.nil? && @rdp_allowed_ips.length < 1
  true
end