Class: BmcApi::Quota

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_bmc_api/models/quota.rb

Overview

Quota.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Quota

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/pnap_bmc_api/models/quota.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::Quota` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::Quota`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'limit')
    self.limit = attributes[:'limit']
  else
    self.limit = nil
  end

  if attributes.key?(:'unit')
    self.unit = attributes[:'unit']
  else
    self.unit = nil
  end

  if attributes.key?(:'used')
    self.used = attributes[:'used']
  else
    self.used = nil
  end

  if attributes.key?(:'quota_edit_limit_request_details')
    if (value = attributes[:'quota_edit_limit_request_details']).is_a?(Array)
      self.quota_edit_limit_request_details = value
    end
  else
    self.quota_edit_limit_request_details = nil
  end
end

Instance Attribute Details

#descriptionObject

The Quota description.



26
27
28
# File 'lib/pnap_bmc_api/models/quota.rb', line 26

def description
  @description
end

#idObject

The ID of the Quota.



20
21
22
# File 'lib/pnap_bmc_api/models/quota.rb', line 20

def id
  @id
end

#limitObject

The limit set for the quota.



32
33
34
# File 'lib/pnap_bmc_api/models/quota.rb', line 32

def limit
  @limit
end

#nameObject

The name of the Quota.



23
24
25
# File 'lib/pnap_bmc_api/models/quota.rb', line 23

def name
  @name
end

#quota_edit_limit_request_detailsObject

Returns the value of attribute quota_edit_limit_request_details.



40
41
42
# File 'lib/pnap_bmc_api/models/quota.rb', line 40

def quota_edit_limit_request_details
  @quota_edit_limit_request_details
end

#statusObject

The status of the quota resource usage.



29
30
31
# File 'lib/pnap_bmc_api/models/quota.rb', line 29

def status
  @status
end

#unitObject

Unit of the quota type. Supported values are ‘COUNT’ and ‘GB’.



35
36
37
# File 'lib/pnap_bmc_api/models/quota.rb', line 35

def unit
  @unit
end

#usedObject

The quota used expressed as a number.



38
39
40
# File 'lib/pnap_bmc_api/models/quota.rb', line 38

def used
  @used
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/pnap_bmc_api/models/quota.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/pnap_bmc_api/models/quota.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/pnap_bmc_api/models/quota.rb', line 65

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'status' => :'status',
    :'limit' => :'limit',
    :'unit' => :'unit',
    :'used' => :'used',
    :'quota_edit_limit_request_details' => :'quotaEditLimitRequestDetails'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/pnap_bmc_api/models/quota.rb', line 360

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/pnap_bmc_api/models/quota.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/pnap_bmc_api/models/quota.rb', line 89

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'status' => :'String',
    :'limit' => :'Integer',
    :'unit' => :'String',
    :'used' => :'Integer',
    :'quota_edit_limit_request_details' => :'Array<QuotaEditLimitRequestDetails>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/pnap_bmc_api/models/quota.rb', line 332

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      status == o.status &&
      limit == o.limit &&
      unit == o.unit &&
      used == o.used &&
      quota_edit_limit_request_details == o.quota_edit_limit_request_details
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


347
348
349
# File 'lib/pnap_bmc_api/models/quota.rb', line 347

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



353
354
355
# File 'lib/pnap_bmc_api/models/quota.rb', line 353

def hash
  [id, name, description, status, limit, unit, used, quota_edit_limit_request_details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/pnap_bmc_api/models/quota.rb', line 177

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @limit.nil?
    invalid_properties.push('invalid value for "limit", limit cannot be nil.')
  end

  if @limit < 0
    invalid_properties.push('invalid value for "limit", must be greater than or equal to 0.')
  end

  if @unit.nil?
    invalid_properties.push('invalid value for "unit", unit cannot be nil.')
  end

  if @used.nil?
    invalid_properties.push('invalid value for "used", used cannot be nil.')
  end

  if @used < 0
    invalid_properties.push('invalid value for "used", must be greater than or equal to 0.')
  end

  if @quota_edit_limit_request_details.nil?
    invalid_properties.push('invalid value for "quota_edit_limit_request_details", quota_edit_limit_request_details cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/pnap_bmc_api/models/quota.rb', line 382

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/pnap_bmc_api/models/quota.rb', line 225

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @description.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["WITHIN_LIMIT", "OVER_LIMIT", "ON_LIMIT"])
  return false unless status_validator.valid?(@status)
  return false if @limit.nil?
  return false if @limit < 0
  return false if @unit.nil?
  return false if @used.nil?
  return false if @used < 0
  return false if @quota_edit_limit_request_details.nil?
  true
end