Class: BmcApi::RebootRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- BmcApi::RebootRequest
- Defined in:
- lib/pnap_bmc_api/models/reboot_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#boot_type ⇒ Object
Specifies whether to boot via ‘IPXE` (requires script) or `STANDARD` (default mechanism, incompatible with `ipxeUrl`).
-
#ipxe_url ⇒ Object
The URL for the iPXE script, used only with ‘IPXE` boot type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RebootRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RebootRequest
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::RebootRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::RebootRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'boot_type') self.boot_type = attributes[:'boot_type'] else self.boot_type = 'STANDARD' end if attributes.key?(:'ipxe_url') self.ipxe_url = attributes[:'ipxe_url'] end end |
Instance Attribute Details
#boot_type ⇒ Object
Specifies whether to boot via ‘IPXE` (requires script) or `STANDARD` (default mechanism, incompatible with `ipxeUrl`).
19 20 21 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 19 def boot_type @boot_type end |
#ipxe_url ⇒ Object
The URL for the iPXE script, used only with ‘IPXE` boot type. If provided, it updates and replaces the existing stored URL; if not provided, the existing URL will be used.
22 23 24 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 22 def ipxe_url @ipxe_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 47 def self.attribute_map { :'boot_type' => :'bootType', :'ipxe_url' => :'ipxeUrl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 174 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 77 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 73 def self.openapi_nullable Set.new([ :'ipxe_url' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 65 def self.openapi_types { :'boot_type' => :'String', :'ipxe_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
152 153 154 155 156 157 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 152 def ==(o) return true if self.equal?(o) self.class == o.class && boot_type == o.boot_type && ipxe_url == o.ipxe_url end |
#eql?(o) ⇒ Boolean
161 162 163 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 161 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
167 168 169 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 167 def hash [boot_type, ipxe_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
108 109 110 111 112 113 114 115 116 117 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 108 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^https?:\/\/.+$/) if !@ipxe_url.nil? && @ipxe_url !~ pattern invalid_properties.push("invalid value for \"ipxe_url\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
121 122 123 124 125 126 127 |
# File 'lib/pnap_bmc_api/models/reboot_request.rb', line 121 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' boot_type_validator = EnumAttributeValidator.new('String', ["IPXE", "STANDARD"]) return false unless boot_type_validator.valid?(@boot_type) return false if !@ipxe_url.nil? && @ipxe_url !~ Regexp.new(/^https?:\/\/.+$/) true end |