Class: BmcApi::ServerProvision

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_bmc_api/models/server_provision.rb

Overview

Provision bare metal server.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ServerProvision

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::ServerProvision` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::ServerProvision`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'hostname')
    self.hostname = attributes[:'hostname']
  else
    self.hostname = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'os')
    self.os = attributes[:'os']
  else
    self.os = nil
  end

  if attributes.key?(:'install_default_ssh_keys')
    self.install_default_ssh_keys = attributes[:'install_default_ssh_keys']
  else
    self.install_default_ssh_keys = true
  end

  if attributes.key?(:'ssh_keys')
    if (value = attributes[:'ssh_keys']).is_a?(Array)
      self.ssh_keys = value
    end
  end

  if attributes.key?(:'ssh_key_ids')
    if (value = attributes[:'ssh_key_ids']).is_a?(Array)
      self.ssh_key_ids = value
    end
  end

  if attributes.key?(:'network_type')
    self.network_type = attributes[:'network_type']
  else
    self.network_type = 'PUBLIC_AND_PRIVATE'
  end

  if attributes.key?(:'os_configuration')
    self.os_configuration = attributes[:'os_configuration']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'network_configuration')
    self.network_configuration = attributes[:'network_configuration']
  end

  if attributes.key?(:'storage_configuration')
    self.storage_configuration = attributes[:'storage_configuration']
  end
end

Instance Attribute Details

#descriptionObject

Description of server.



23
24
25
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 23

def description
  @description
end

#hostnameObject

Hostname of server.



20
21
22
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 20

def hostname
  @hostname
end

#install_default_ssh_keysObject

Whether or not to install SSH keys marked as default in addition to any SSH keys specified in this request.



29
30
31
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 29

def install_default_ssh_keys
  @install_default_ssh_keys
end

#network_configurationObject

Returns the value of attribute network_configuration.



45
46
47
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 45

def network_configuration
  @network_configuration
end

#network_typeObject

The type of network configuration for this server.
Currently this field should be set to ‘PUBLIC_AND_PRIVATE`, `PRIVATE_ONLY`, `PUBLIC_ONLY` or `USER_DEFINED`.
Setting the `force` query parameter to `true` allows you to configure network configuration type as `NONE`.



38
39
40
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 38

def network_type
  @network_type
end

#osObject

The server’s OS ID used when the server was created. Currently this field should be set to either ‘ubuntu/bionic`, `ubuntu/focal`, `ubuntu/jammy`, `ubuntu/jammy+pytorch`, `ubuntu/noble`, `centos/centos7`, `centos/centos8`, `windows/srv2019std`, `windows/srv2019dc`, `windows/srv2022std`, `windows/srv2022dc`, `windows/srv2025std`, `windows/srv2025dc`, `esxi/esxi70`, `esxi/esxi80`, `almalinux/almalinux8`, `almalinux/almalinux9`, `rockylinux/rockylinux8`, `rockylinux/rockylinux9`, `virtuozzo/virtuozzo7`, `oraclelinux/oraclelinux9`, `debian/bullseye`, `debian/bookworm`, `debian/trixie`, `proxmox/bullseye`, `proxmox/proxmox8`, `proxmox/proxmox9`,`netris/controller`, `netris/softgate_1g`, `netris/softgate_10g`, `netris/softgate_25g` or `ipxe`.



26
27
28
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 26

def os
  @os
end

#os_configurationObject

Returns the value of attribute os_configuration.



40
41
42
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 40

def os_configuration
  @os_configuration
end

#ssh_key_idsObject

A list of SSH key IDs that will be installed on the server in addition to any SSH keys specified in this request.



35
36
37
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 35

def ssh_key_ids
  @ssh_key_ids
end

#ssh_keysObject

A list of SSH keys that will be installed on the server.



32
33
34
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 32

def ssh_keys
  @ssh_keys
end

#storage_configurationObject

Returns the value of attribute storage_configuration.



47
48
49
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 47

def storage_configuration
  @storage_configuration
end

#tagsObject

Tags to set to the server. To create a new tag or list all the existing tags that you can use, refer to [Tags API](developers.phoenixnap.com/docs/tags/1/overview).



43
44
45
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 43

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 50

def self.attribute_map
  {
    :'hostname' => :'hostname',
    :'description' => :'description',
    :'os' => :'os',
    :'install_default_ssh_keys' => :'installDefaultSshKeys',
    :'ssh_keys' => :'sshKeys',
    :'ssh_key_ids' => :'sshKeyIds',
    :'network_type' => :'networkType',
    :'os_configuration' => :'osConfiguration',
    :'tags' => :'tags',
    :'network_configuration' => :'networkConfiguration',
    :'storage_configuration' => :'storageConfiguration'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 300

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 77

def self.openapi_types
  {
    :'hostname' => :'String',
    :'description' => :'String',
    :'os' => :'String',
    :'install_default_ssh_keys' => :'Boolean',
    :'ssh_keys' => :'Array<String>',
    :'ssh_key_ids' => :'Array<String>',
    :'network_type' => :'String',
    :'os_configuration' => :'OsConfiguration',
    :'tags' => :'Array<TagAssignmentRequest>',
    :'network_configuration' => :'NetworkConfiguration',
    :'storage_configuration' => :'StorageConfiguration'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 269

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      hostname == o.hostname &&
      description == o.description &&
      os == o.os &&
      install_default_ssh_keys == o.install_default_ssh_keys &&
      ssh_keys == o.ssh_keys &&
      ssh_key_ids == o.ssh_key_ids &&
      network_type == o.network_type &&
      os_configuration == o.os_configuration &&
      tags == o.tags &&
      network_configuration == o.network_configuration &&
      storage_configuration == o.storage_configuration
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


287
288
289
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 287

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



293
294
295
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 293

def hash
  [hostname, description, os, install_default_ssh_keys, ssh_keys, ssh_key_ids, network_type, os_configuration, tags, network_configuration, storage_configuration].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 176

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @hostname.nil?
    invalid_properties.push('invalid value for "hostname", hostname cannot be nil.')
  end

  if @hostname.to_s.length > 100
    invalid_properties.push('invalid value for "hostname", the character length must be smaller than or equal to 100.')
  end

  if @hostname.to_s.length < 1
    invalid_properties.push('invalid value for "hostname", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9().-])+$/)
  if @hostname !~ pattern
    invalid_properties.push("invalid value for \"hostname\", must conform to the pattern #{pattern}.")
  end

  if !@description.nil? && @description.to_s.length > 250
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.')
  end

  if @os.nil?
    invalid_properties.push('invalid value for "os", os cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 322

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



209
210
211
212
213
214
215
216
217
218
# File 'lib/pnap_bmc_api/models/server_provision.rb', line 209

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @hostname.nil?
  return false if @hostname.to_s.length > 100
  return false if @hostname.to_s.length < 1
  return false if @hostname !~ Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9().-])+$/)
  return false if !@description.nil? && @description.to_s.length > 250
  return false if @os.nil?
  true
end