Class: BmcApi::ServerPublicNetwork

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_bmc_api/models/server_public_network.rb

Overview

Public network details of bare metal server.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ServerPublicNetwork

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::ServerPublicNetwork` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::ServerPublicNetwork`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'ips')
    if (value = attributes[:'ips']).is_a?(Array)
      self.ips = value
    end
  else
    self.ips = nil
  end

  if attributes.key?(:'status_description')
    self.status_description = attributes[:'status_description']
  end

  if attributes.key?(:'compute_slaac_ip')
    self.compute_slaac_ip = attributes[:'compute_slaac_ip']
  end

  if attributes.key?(:'vlan_id')
    self.vlan_id = attributes[:'vlan_id']
  end
end

Instance Attribute Details

#compute_slaac_ipObject

(Write-only) Requests Stateless Address Autoconfiguration (SLAAC). Applicable for Network which contains IPv6 block(s).



29
30
31
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 29

def compute_slaac_ip
  @compute_slaac_ip
end

#idObject

The network identifier.



20
21
22
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 20

def id
  @id
end

#ipsObject

Configurable/configured IPs on the server.
At least 1 IP address is required. Valid IP formats include single IP addresses or IP ranges (IPv4 or IPv6). All IPs must be within the network’s range.
Setting the ‘computeSlaacIp` field to `true` allows you to provide an empty array of IPs.
Referencing network as OS native network allows you to provide an empty array of IPs.
Additionally, setting the `force` query parameter to `true` allows you to:<ul> <li> Assign no specific IP addresses by designating an empty array of IPs. Note that at least one IP is required for the gateway address to be selected from this network. <li> Assign one or more IP addresses which are already configured on other resource(s) in network.</ul>



23
24
25
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 23

def ips
  @ips
end

#status_descriptionObject

(Read-only) The status of the assignment to the network.



26
27
28
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 26

def status_description
  @status_description
end

#vlan_idObject

(Read-only) The VLAN on which this network has been configured within the network switch.



32
33
34
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 32

def vlan_id
  @vlan_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 35

def self.attribute_map
  {
    :'id' => :'id',
    :'ips' => :'ips',
    :'status_description' => :'statusDescription',
    :'compute_slaac_ip' => :'computeSlaacIp',
    :'vlan_id' => :'vlanId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 187

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 56

def self.openapi_types
  {
    :'id' => :'String',
    :'ips' => :'Array<String>',
    :'status_description' => :'String',
    :'compute_slaac_ip' => :'Boolean',
    :'vlan_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      ips == o.ips &&
      status_description == o.status_description &&
      compute_slaac_ip == o.compute_slaac_ip &&
      vlan_id == o.vlan_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


174
175
176
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 174

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



180
181
182
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 180

def hash
  [id, ips, status_description, compute_slaac_ip, vlan_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @ips.nil?
    invalid_properties.push('invalid value for "ips", ips cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 209

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
137
138
# File 'lib/pnap_bmc_api/models/server_public_network.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @ips.nil?
  true
end