Class: BmcApi::TagAssignment

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_bmc_api/models/tag_assignment.rb

Overview

Tag assigned to resource.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TagAssignment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::TagAssignment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::TagAssignment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'is_billing_tag')
    self.is_billing_tag = attributes[:'is_billing_tag']
  else
    self.is_billing_tag = nil
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end
end

Instance Attribute Details

#created_byObject

Who the tag was created by.



32
33
34
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 32

def created_by
  @created_by
end

#idObject

The unique id of the tag.



20
21
22
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 20

def id
  @id
end

#is_billing_tagObject

Whether or not to show the tag as part of billing and invoices



29
30
31
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 29

def is_billing_tag
  @is_billing_tag
end

#nameObject

The name of the tag.



23
24
25
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 23

def name
  @name
end

#valueObject

The value of the tag assigned to the resource.



26
27
28
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 26

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 57

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'value' => :'value',
    :'is_billing_tag' => :'isBillingTag',
    :'created_by' => :'createdBy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 236

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 78

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'value' => :'String',
    :'is_billing_tag' => :'Boolean',
    :'created_by' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      value == o.value &&
      is_billing_tag == o.is_billing_tag &&
      created_by == o.created_by
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 223

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



229
230
231
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 229

def hash
  [id, name, value, is_billing_tag, created_by].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 139

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @is_billing_tag.nil?
    invalid_properties.push('invalid value for "is_billing_tag", is_billing_tag cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 258

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



159
160
161
162
163
164
165
166
167
# File 'lib/pnap_bmc_api/models/tag_assignment.rb', line 159

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @is_billing_tag.nil?
  created_by_validator = EnumAttributeValidator.new('String', ["USER", "SYSTEM"])
  return false unless created_by_validator.valid?(@created_by)
  true
end