Class: BmcApi::OsConfiguration
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- BmcApi::OsConfiguration
- Defined in:
- lib/pnap_bmc_api/models/os_configuration.rb
Overview
OS specific configuration properties.
Instance Attribute Summary collapse
-
#cloud_init ⇒ Object
Returns the value of attribute cloud_init.
-
#esxi ⇒ Object
Returns the value of attribute esxi.
-
#i_pxe ⇒ Object
Returns the value of attribute i_pxe.
-
#install_os_to_ram ⇒ Object
If true, OS will be installed to and booted from the server’s RAM.
-
#management_access_allowed_ips ⇒ Object
List of IPs allowed to access the Management UI.
-
#management_ui_url ⇒ Object
(Read-only) The URL of the management UI which will only be returned in response to provisioning a server.
-
#netris_controller ⇒ Object
Returns the value of attribute netris_controller.
-
#netris_softgate ⇒ Object
Returns the value of attribute netris_softgate.
-
#root_password ⇒ Object
(Read-only) Auto-generated password set for user ‘root’ on an ESXi or Proxmox server.
The password is not stored and therefore will only be returned in response to provisioning a server. -
#windows ⇒ Object
Returns the value of attribute windows.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OsConfiguration
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OsConfiguration
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::OsConfiguration` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::OsConfiguration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'netris_controller') self.netris_controller = attributes[:'netris_controller'] end if attributes.key?(:'netris_softgate') self.netris_softgate = attributes[:'netris_softgate'] end if attributes.key?(:'windows') self.windows = attributes[:'windows'] end if attributes.key?(:'root_password') self.root_password = attributes[:'root_password'] end if attributes.key?(:'management_ui_url') self.management_ui_url = attributes[:'management_ui_url'] end if attributes.key?(:'management_access_allowed_ips') if (value = attributes[:'management_access_allowed_ips']).is_a?(Array) self.management_access_allowed_ips = value end end if attributes.key?(:'install_os_to_ram') self.install_os_to_ram = attributes[:'install_os_to_ram'] else self.install_os_to_ram = false end if attributes.key?(:'esxi') self.esxi = attributes[:'esxi'] end if attributes.key?(:'cloud_init') self.cloud_init = attributes[:'cloud_init'] end if attributes.key?(:'i_pxe') self.i_pxe = attributes[:'i_pxe'] end end |
Instance Attribute Details
#cloud_init ⇒ Object
Returns the value of attribute cloud_init.
39 40 41 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 39 def cloud_init @cloud_init end |
#esxi ⇒ Object
Returns the value of attribute esxi.
37 38 39 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 37 def esxi @esxi end |
#i_pxe ⇒ Object
Returns the value of attribute i_pxe.
41 42 43 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 41 def i_pxe @i_pxe end |
#install_os_to_ram ⇒ Object
If true, OS will be installed to and booted from the server’s RAM. On restart RAM OS will be lost and the server will not be reachable unless a custom bootable OS has been deployed. Follow the <a href=‘phoenixnap.com/kb/bmc-custom-os’ target=‘_blank’>instructions</a> on how to install custom OS on BMC. Only supported for ubuntu/focal and ubuntu/jammy.
35 36 37 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 35 def install_os_to_ram @install_os_to_ram end |
#management_access_allowed_ips ⇒ Object
List of IPs allowed to access the Management UI. Supported in single IP, CIDR and range format. When undefined, Management UI is disabled. This will only be returned in response to provisioning a server.
32 33 34 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 32 def management_access_allowed_ips @management_access_allowed_ips end |
#management_ui_url ⇒ Object
(Read-only) The URL of the management UI which will only be returned in response to provisioning a server.
29 30 31 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 29 def management_ui_url @management_ui_url end |
#netris_controller ⇒ Object
Returns the value of attribute netris_controller.
19 20 21 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 19 def netris_controller @netris_controller end |
#netris_softgate ⇒ Object
Returns the value of attribute netris_softgate.
21 22 23 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 21 def netris_softgate @netris_softgate end |
#root_password ⇒ Object
(Read-only) Auto-generated password set for user ‘root’ on an ESXi or Proxmox server.
The password is not stored and therefore will only be returned in response to provisioning a server. Copy and save it for future reference.
26 27 28 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 26 def root_password @root_password end |
#windows ⇒ Object
Returns the value of attribute windows.
23 24 25 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 23 def windows @windows end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 44 def self.attribute_map { :'netris_controller' => :'netrisController', :'netris_softgate' => :'netrisSoftgate', :'windows' => :'windows', :'root_password' => :'rootPassword', :'management_ui_url' => :'managementUiUrl', :'management_access_allowed_ips' => :'managementAccessAllowedIps', :'install_os_to_ram' => :'installOsToRam', :'esxi' => :'esxi', :'cloud_init' => :'cloudInit', :'i_pxe' => :'iPXE' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 218 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 70 def self.openapi_types { :'netris_controller' => :'OsConfigurationNetrisController', :'netris_softgate' => :'OsConfigurationNetrisSoftgate', :'windows' => :'OsConfigurationWindows', :'root_password' => :'String', :'management_ui_url' => :'String', :'management_access_allowed_ips' => :'Array<String>', :'install_os_to_ram' => :'Boolean', :'esxi' => :'EsxiOsConfiguration', :'cloud_init' => :'OsConfigurationCloudInit', :'i_pxe' => :'OsConfigurationIPXE' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 188 def ==(o) return true if self.equal?(o) self.class == o.class && netris_controller == o.netris_controller && netris_softgate == o.netris_softgate && windows == o.windows && root_password == o.root_password && management_ui_url == o.management_ui_url && management_access_allowed_ips == o.management_access_allowed_ips && install_os_to_ram == o.install_os_to_ram && esxi == o.esxi && cloud_init == o.cloud_init && i_pxe == o.i_pxe end |
#eql?(o) ⇒ Boolean
205 206 207 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 205 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
211 212 213 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 211 def hash [netris_controller, netris_softgate, windows, root_password, management_ui_url, management_access_allowed_ips, install_os_to_ram, esxi, cloud_init, i_pxe].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
154 155 156 157 158 159 160 161 162 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 154 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@management_access_allowed_ips.nil? && @management_access_allowed_ips.length < 1 invalid_properties.push('invalid value for "management_access_allowed_ips", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 240 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
166 167 168 169 170 |
# File 'lib/pnap_bmc_api/models/os_configuration.rb', line 166 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@management_access_allowed_ips.nil? && @management_access_allowed_ips.length < 1 true end |