Class: BmcApi::OsConfigurationNetrisSoftgate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- BmcApi::OsConfigurationNetrisSoftgate
- Defined in:
- lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb
Overview
Netris Softgate configuration properties. Follow <a href=‘phoenixnap.com/kb/netris-bare-metal-cloud#deploy-netris-softgate’ target=‘_blank’>instructions</a> for retrieving the required details.
Instance Attribute Summary collapse
-
#controller_address ⇒ Object
(Write-only) IP address or hostname through which to reach the Netris Controller.
-
#controller_auth_key ⇒ Object
(Write-only) The authentication key of the Netris Controller to connect to.
-
#controller_version ⇒ Object
(Write-only) The version of the Netris Controller to connect to.
-
#host_os ⇒ Object
(Read-only) Host OS on which the Netris Softgate is installed.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OsConfigurationNetrisSoftgate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OsConfigurationNetrisSoftgate
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::OsConfigurationNetrisSoftgate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::OsConfigurationNetrisSoftgate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'host_os') self.host_os = attributes[:'host_os'] end if attributes.key?(:'controller_address') self.controller_address = attributes[:'controller_address'] end if attributes.key?(:'controller_version') self.controller_version = attributes[:'controller_version'] end if attributes.key?(:'controller_auth_key') self.controller_auth_key = attributes[:'controller_auth_key'] end end |
Instance Attribute Details
#controller_address ⇒ Object
(Write-only) IP address or hostname through which to reach the Netris Controller.
23 24 25 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 23 def controller_address @controller_address end |
#controller_auth_key ⇒ Object
(Write-only) The authentication key of the Netris Controller to connect to. Required for the softgate agent to be able to interact with the Netris Controller.
29 30 31 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 29 def controller_auth_key @controller_auth_key end |
#controller_version ⇒ Object
(Write-only) The version of the Netris Controller to connect to.
26 27 28 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 26 def controller_version @controller_version end |
#host_os ⇒ Object
(Read-only) Host OS on which the Netris Softgate is installed.
20 21 22 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 20 def host_os @host_os end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 32 def self.attribute_map { :'host_os' => :'hostOs', :'controller_address' => :'controllerAddress', :'controller_version' => :'controllerVersion', :'controller_auth_key' => :'controllerAuthKey' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 192 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 62 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 52 def self.openapi_types { :'host_os' => :'String', :'controller_address' => :'String', :'controller_version' => :'String', :'controller_auth_key' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 168 def ==(o) return true if self.equal?(o) self.class == o.class && host_os == o.host_os && controller_address == o.controller_address && controller_version == o.controller_version && controller_auth_key == o.controller_auth_key end |
#eql?(o) ⇒ Boolean
179 180 181 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 179 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
185 186 187 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 185 def hash [host_os, controller_address, controller_version, controller_auth_key].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 102 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@controller_address.nil? && @controller_address.to_s.length > 253 invalid_properties.push('invalid value for "controller_address", the character length must be smaller than or equal to 253.') end pattern = Regexp.new(/^(?!-)[\w\-]{1,63}(?<!-)(\.(?!-)[\w\-]{1,63}(?<!-))*$/) if !@controller_address.nil? && @controller_address !~ pattern invalid_properties.push("invalid value for \"controller_address\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\S+$/) if !@controller_auth_key.nil? && @controller_auth_key !~ pattern invalid_properties.push("invalid value for \"controller_auth_key\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
124 125 126 127 128 129 130 |
# File 'lib/pnap_bmc_api/models/os_configuration_netris_softgate.rb', line 124 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@controller_address.nil? && @controller_address.to_s.length > 253 return false if !@controller_address.nil? && @controller_address !~ Regexp.new(/^(?!-)[\w\-]{1,63}(?<!-)(\.(?!-)[\w\-]{1,63}(?<!-))*$/) return false if !@controller_auth_key.nil? && @controller_auth_key !~ Regexp.new(/^\S+$/) true end |