Class: BmcApi::ServerPrivateNetwork
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- BmcApi::ServerPrivateNetwork
- Defined in:
- lib/pnap_bmc_api/models/server_private_network.rb
Overview
Private network details of bare metal server.
Instance Attribute Summary collapse
-
#dhcp ⇒ Object
Determines whether DHCP is enabled for this server.
The following restrictions apply when enabling DHCP:<ul> <li> DHCP support is limited to servers configured exclusively with private networks (PRIVATE_ONLY). -
#id ⇒ Object
The network identifier.
-
#ips ⇒ Object
IPs to configure/configured on the server.
Valid IP formats are single IPv4 addresses or IPv4 ranges. -
#status_description ⇒ Object
(Read-only) The status of the network.
-
#vlan_id ⇒ Object
(Read-only) The VLAN on which this network has been configured within the network switch.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ServerPrivateNetwork
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ServerPrivateNetwork
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `BmcApi::ServerPrivateNetwork` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `BmcApi::ServerPrivateNetwork`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'ips') if (value = attributes[:'ips']).is_a?(Array) self.ips = value end end if attributes.key?(:'dhcp') self.dhcp = attributes[:'dhcp'] else self.dhcp = false end if attributes.key?(:'status_description') self.status_description = attributes[:'status_description'] end if attributes.key?(:'vlan_id') self.vlan_id = attributes[:'vlan_id'] end end |
Instance Attribute Details
#dhcp ⇒ Object
Determines whether DHCP is enabled for this server.
The following restrictions apply when enabling DHCP:<ul> <li> DHCP support is limited to servers configured exclusively with private networks (PRIVATE_ONLY). <li> DHCP value needs to be consistent across all server-configured private networks. <li> The server does not support manual gateway address configuration. <li> Private IP addresses for network cannot be specified.</ul> Note: Not supported on Proxmox OS.
26 27 28 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 26 def dhcp @dhcp end |
#id ⇒ Object
The network identifier.
20 21 22 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 20 def id @id end |
#ips ⇒ Object
IPs to configure/configured on the server.
Valid IP formats are single IPv4 addresses or IPv4 ranges. IPs must be within the network’s range. Should be null or empty list if DHCP is true.
If field is undefined and DHCP is false, next available IP in network will be automatically allocated.
If the network contains a membership of type ‘storage’, the first twelve IPs are already reserved by BMC and not usable.
Setting the ‘force` query parameter to `true` allows you to:<ul> <li> Assign no specific IP addresses by designating an empty array of IPs. Note that at least one IP is required for the gateway address to be selected from this network. <li> Assign one or more IP addresses which are already configured on other resource(s) in network. <li> Assign IP addresses which are considered as reserved in network.</ul>
23 24 25 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 23 def ips @ips end |
#status_description ⇒ Object
(Read-only) The status of the network.
29 30 31 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 29 def status_description @status_description end |
#vlan_id ⇒ Object
(Read-only) The VLAN on which this network has been configured within the network switch.
32 33 34 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 32 def vlan_id @vlan_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 35 def self.attribute_map { :'id' => :'id', :'ips' => :'ips', :'dhcp' => :'dhcp', :'status_description' => :'statusDescription', :'vlan_id' => :'vlanId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 67 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 56 def self.openapi_types { :'id' => :'String', :'ips' => :'Array<String>', :'dhcp' => :'Boolean', :'status_description' => :'String', :'vlan_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
166 167 168 169 170 171 172 173 174 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 166 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && ips == o.ips && dhcp == o.dhcp && status_description == o.status_description && vlan_id == o.vlan_id end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 184 def hash [id, ips, dhcp, status_description, vlan_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 117 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if !@ips.nil? && @ips.length > 256 invalid_properties.push('invalid value for "ips", number of items must be less than or equal to 256.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
133 134 135 136 137 138 |
# File 'lib/pnap_bmc_api/models/server_private_network.rb', line 133 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if !@ips.nil? && @ips.length > 256 true end |